---
title: "Validation Result Store"
---
import UniversalMap from '/docs/images/universal_map/_universal_map.mdx';
import TechnicalTag from '../term_tags/_tag.mdx';
import SetupHeader from '/docs/images/universal_map/_um_setup_header.mdx'
import CreateHeader from '/docs/images/universal_map/_um_create_header.mdx';
import ValidateHeader from '/docs/images/universal_map/_um_validate_header.mdx';


<UniversalMap setup='active' connect='inactive' create='active' validate='active'/> 

## Overview

### Definition

A Validation Result Store is a connector to store and retrieve information about objects generated when data is Validated against an Expectation Suite.

### Features and promises

Validation Result Stores allow you to store and retrieve <TechnicalTag relative="../" tag="validation_result" text="Validation Results" /> that have been generated by <TechnicalTag relative="../" tag="checkpoint" text="Checkpoints" />.  These Stores can be accessed and configured through the <TechnicalTag relative="../" tag="data_context" text="Data Context" />, but entries are added to them automatically when a Checkpoint with the appropriate <TechnicalTag relative="../" tag="action" text="Action" /> in its `action_list` completes running.  A configured Validation Result Store is required in order to work with Great Expectations.  A local configuration for a Validation Result Store will be added automatically to `great_expectations.yml` when you initialize your Data Context for the first time.

Validation Result Stores ensure that Validation Results are accessible via the Data Context for review and rendering into <TechnicalTag relative="../" tag="data_docs" text="Data Docs" />.  Generally speaking, while working with Great Expectations to <TechnicalTag relative="../" tag="validation" text="Validate" /> data you will not need to interact with a Validation Result Store directly outside configuring the <TechnicalTag relative="../" tag="store" text="Store" /> or configuring <TechnicalTag relative="../" tag="evaluation_parameter" text="Evaluation Parameters" /> that reference <TechnicalTag relative="../" tag="metric" text="Metrics" /> which can be found in a stored Validation Result.  Instead, your Data Context will use your Validation Result Store behind the scenes when Validation Results are retrieved or stored.

### Relationship to other objects

Validation Result Stores can be used to store and retrieve Validation Results and associated metadata.  The process of storing this information is typically executed by an Action in a Checkpoint's `action_list`.  Metrics found in the Validation Results stored in Validation Result Stores can also be accessed as Evaluation Parameters when defining Expectations.

## Use cases

<SetupHeader/>

When you initialize your Data Context for the first time, a configuration for a local Validation Result Store will automatically be added to `great_expectations.yml`. You may change this configuration to work with different environments. 

- For more information on configuring a Validation Results Store for a specific environment, please refer to our [in-depth guides on Validation Result Store configurations.](../guides/setup/index.md#validation-result-stores)


<CreateHeader/>

When interactively creating Expectations that rely on Evaluation Parameters, it is possible to use existing Validation Results that have stored Metrics to populate those parameters.  If these Validation Results are not available in memory, then the only way to access them is by retrieving them through a Validation Result Store (if they were stored previously).

<ValidateHeader/>

When validating Data with a Checkpoint, Validation Results will be stored by the `StoreValidationResultAction` if it exists in the Checkpoint's `action_list`.  This will use a Validation Result Store to store the Validation Result and associated metadata.  Some Expectations may also use Evaluation Parameters which are configured to pull Metrics from Validation Results that are available through the Validation Result Store.

## API basics

### How to access

You will not typically need direct access to your Validation Result Store.  Instead, your Data Context will use your Validation Result Store behind the scenes when storing or retrieving Validation Results.  Most of your interaction with the Validation Results Store will take place during Setup, if you have need to configure your Validation Result Store beyond the default that is provided when you initialize your Data Context.

### Configuration

For details on how to configure a Validation Result Store, please reference the relevant how-to guide:

- [How to configure a Validation Result store in Amazon S3](../guides/setup/configuring_metadata_stores/how_to_configure_a_validation_result_store_in_amazon_s3.md)
- [How to configure a Validation Result store in Azure Blob Storage](../guides/setup/configuring_metadata_stores/how_to_configure_a_validation_result_store_in_azure_blob_storage.md)
- [How to configure a Validation Result store in GCS](../guides/setup/configuring_metadata_stores/how_to_configure_a_validation_result_store_in_gcs.md)
- [How to configure a Validation Result store on a filesystem](../guides/setup/configuring_metadata_stores/how_to_configure_a_validation_result_store_on_a_filesystem.md)
- [How to configure a Validation Result store to PostgreSQL](../guides/setup/configuring_metadata_stores/how_to_configure_a_validation_result_store_to_postgresql.md)

